@@ -137,6 +137,7 @@ long cm_GetServerList(struct cm_fid *fidp, struct cm_user *userp,
  *
  * volSyncp and/or cbrp may also be NULL.
  */
+int
 cm_Analyze(cm_conn_t *connp, cm_user_t *userp, cm_req_t *reqp,
 	struct cm_fid *fidp,
 	AFSVolSync *volSyncp, cm_callbackRequest_t *cbrp, long errorCode)
@@ -403,8 +404,8 @@ long cm_ConnByMServers(cm_serverRef_t *serversp, cm_user_t *usersp,
 void cm_GCConnections(cm_server_t *serverp)
 {
 	cm_conn_t *tcp;
-        cm_conn_t **lcpp;
-        cm_user_t *userp;
+    cm_conn_t **lcpp;
+    cm_user_t *userp;
 
 	lock_ObtainWrite(&cm_connLock);
 	lcpp = &serverp->connsp;
@@ -412,38 +413,38 @@ void cm_GCConnections(cm_server_t *serverp)
 		userp = tcp->userp;
 		if (userp && tcp->refCount == 0 && (userp->vcRefs == 0)) {
 			/* do the deletion of this guy */
-                        cm_ReleaseUser(userp);
-                        *lcpp = tcp->nextp;
+            cm_ReleaseUser(userp);
+            *lcpp = tcp->nextp;
 			rx_DestroyConnection(tcp->callp);
-                        lock_FinalizeMutex(&tcp->mx);
-                        free(tcp);
-                }
-                else {
-			/* just advance to the next */
-                        lcpp = &tcp->nextp;
-                }
+            lock_FinalizeMutex(&tcp->mx);
+            free(tcp);
         }
+        else {
+			/* just advance to the next */
+            lcpp = &tcp->nextp;
+        }
+    }
 	lock_ReleaseWrite(&cm_connLock);
 }
 
 static void cm_NewRXConnection(cm_conn_t *tcp, cm_ucell_t *ucellp,
 	cm_server_t *serverp)
 {
-        unsigned short port;
-        int serviceID;
-        int secIndex;
-        struct rx_securityClass *secObjp;
+    unsigned short port;
+    int serviceID;
+    int secIndex;
+    struct rx_securityClass *secObjp;
 	afs_int32 level;
 
 	if (serverp->type == CM_SERVER_VLDB) {
 		port = htons(7003);
-                serviceID = 52;
-        }
-        else {
+        serviceID = 52;
+    }
+    else {
 		osi_assert(serverp->type == CM_SERVER_FILE);
-                port = htons(7000);
-                serviceID = 1;
-        }
+        port = htons(7000);
+        serviceID = 1;
+    }
 	if (ucellp->flags & CM_UCELLFLAG_RXKAD) {
 		secIndex = 2;
 		if (cryptall) {
@@ -452,67 +453,69 @@ static void cm_NewRXConnection(cm_conn_t *tcp, cm_ucell_t *ucellp,
 		} else {
 			level = rxkad_clear;
 		}
-                secObjp = rxkad_NewClientSecurityObject(level,
-			&ucellp->sessionKey, ucellp->kvno,
-			ucellp->ticketLen, ucellp->ticketp);
-        }
-        else {
-		/* normal auth */
-                secIndex = 0;
-                secObjp = rxnull_NewClientSecurityObject();
-        }
+        secObjp = rxkad_NewClientSecurityObject(level,
+                                                &ucellp->sessionKey, ucellp->kvno,
+                                                ucellp->ticketLen, ucellp->ticketp);    
+    }
+    else {
+        /* normal auth */
+        secIndex = 0;
+        secObjp = rxnull_NewClientSecurityObject();
+    }
 	osi_assert(secObjp != NULL);
-        tcp->callp = rx_NewConnection(serverp->addr.sin_addr.s_addr,
-               	port,
-        	serviceID,
-		secObjp,
-                secIndex);
+    tcp->callp = rx_NewConnection(serverp->addr.sin_addr.s_addr,
+                                  port,
+                                  serviceID,
+                                  secObjp,
+                                  secIndex);
 	rx_SetConnDeadTime(tcp->callp, CM_CONN_CONNDEADTIME);
 	rx_SetConnHardDeadTime(tcp->callp, CM_CONN_HARDDEADTIME);
 	tcp->ucgen = ucellp->gen;
+    if (secObjp)
+        rxs_Release(secObjp);   /* Decrement the initial refCount */
 }
 
 long cm_ConnByServer(cm_server_t *serverp, cm_user_t *userp, cm_conn_t **connpp)
 {
 	cm_conn_t *tcp;
-        cm_ucell_t *ucellp;
+    cm_ucell_t *ucellp;
 
 	lock_ObtainMutex(&userp->mx);
 	lock_ObtainWrite(&cm_connLock);
 	for(tcp = serverp->connsp; tcp; tcp=tcp->nextp) {
 		if (tcp->userp == userp) break;
-        }
+    }
 	/* find ucell structure */
-        ucellp = cm_GetUCell(userp, serverp->cellp);
+    ucellp = cm_GetUCell(userp, serverp->cellp);
 	if (!tcp) {
 		tcp = malloc(sizeof(*tcp));
-                memset(tcp, 0, sizeof(*tcp));
-                tcp->nextp = serverp->connsp;
-                serverp->connsp = tcp;
-                tcp->userp = userp;
-                cm_HoldUser(userp);
-                lock_InitializeMutex(&tcp->mx, "cm_conn_t mutex");
-                tcp->serverp = serverp;
+        memset(tcp, 0, sizeof(*tcp));
+        tcp->nextp = serverp->connsp;
+        serverp->connsp = tcp;
+        cm_HoldUser(userp);
+        tcp->userp = userp;
+        lock_InitializeMutex(&tcp->mx, "cm_conn_t mutex");
+        tcp->serverp = serverp;
 		tcp->cryptlevel = rxkad_clear;
 		cm_NewRXConnection(tcp, ucellp, serverp);
 		tcp->refCount = 1;
-        }
+    }
 	else {
 		if ((tcp->ucgen < ucellp->gen) || (tcp->cryptlevel != cryptall))
 		{
 			rx_DestroyConnection(tcp->callp);
 			cm_NewRXConnection(tcp, ucellp, serverp);
 		}
-        	tcp->refCount++;
+        tcp->refCount++;
 	}
 	lock_ReleaseWrite(&cm_connLock);
-        lock_ReleaseMutex(&userp->mx);
+    lock_ReleaseMutex(&userp->mx);
 
 	/* return this pointer to our caller */
-        osi_Log1(afsd_logp, "cm_ConnByServer returning conn 0x%x", (long) tcp);
+    osi_Log1(afsd_logp, "cm_ConnByServer returning conn 0x%x", (long) tcp);
 	*connpp = tcp;
 
-        return 0;
+    return 0;
 }
 
 long cm_Conn(struct cm_fid *fidp, struct cm_user *userp, cm_req_t *reqp,
